# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.setup_tools_api import SetupToolsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestSetupToolsApi(unittest.TestCase):
    """SetupToolsApi unit test stubs"""

    def setUp(self):
        self.api = SetupToolsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_spreadsheet(self):
        """Test case for get_spreadsheet

        Gets the template spreadsheet for the given job type  # noqa: E501
        """
        pass

    def test_run_setup_tool_job(self):
        """Test case for run_setup_tool_job

        Enqueues a job of the given type to be run  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'location': 'LocationChild',
        'date_occurred': 'datetime',
        'description': 'str',
        'activity_category': 'CaseContentType',
        'group': 'GroupChild',
        'indicator': 'IndicatorChild',
        'activity_codes': 'list[ActivityCodeChild]',
        'activity_document': 'DocumentChild',
        'title': 'str',
        'evidence_indicator': 'IndicatorChild',
        'created': 'datetime',
        'created_by': 'str',
        'modified': 'datetime',
        'modified_by': 'str',
        'savings': 'float',
        'hierarchy': 'list[HierarchyChild]'
    }

    attribute_map = {
        'id': 'Id',
        'location': 'Location',
        'date_occurred': 'DateOccurred',
        'description': 'Description',
        'activity_category': 'ActivityCategory',
        'group': 'Group',
        'indicator': 'Indicator',
        'activity_codes': 'ActivityCodes',
        'activity_document': 'ActivityDocument',
        'title': 'Title',
        'evidence_indicator': 'EvidenceIndicator',
        'created': 'Created',
        'created_by': 'CreatedBy',
        'modified': 'Modified',
        'modified_by': 'ModifiedBy',
        'savings': 'Savings',
        'hierarchy': 'Hierarchy'
    }

    def __init__(self, id=None, location=None, date_occurred=None, description=None, activity_category=None, group=None, indicator=None, activity_codes=None, activity_document=None, title=None, evidence_indicator=None, created=None, created_by=None, modified=None, modified_by=None, savings=None, hierarchy=None):  # noqa: E501
        """ActivityResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._location = None
        self._date_occurred = None
        self._description = None
        self._activity_category = None
        self._group = None
        self._indicator = None
        self._activity_codes = None
        self._activity_document = None
        self._title = None
        self._evidence_indicator = None
        self._created = None
        self._created_by = None
        self._modified = None
        self._modified_by = None
        self._savings = None
        self._hierarchy = None
        self.discriminator = None
        self.id = id
        self.location = location
        self.date_occurred = date_occurred
        self.description = description
        self.activity_category = activity_category
        if group is not None:
            self.group = group
        if indicator is not None:
            self.indicator = indicator
        self.activity_codes = activity_codes
        self.activity_document = activity_document
        self.title = title
        if evidence_indicator is not None:
            self.evidence_indicator = evidence_indicator
        self.created = created
        self.created_by = created_by
        self.modified = modified
        self.modified_by = modified_by
        self.savings = savings
        self.hierarchy = hierarchy

    @property
    def id(self):
        """Gets the id of this ActivityResponse.  # noqa: E501


        :return: The id of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ActivityResponse.


        :param id: The id of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def location(self):
        """Gets the location of this ActivityResponse.  # noqa: E501


        :return: The location of this ActivityResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ActivityResponse.


        :param location: The location of this ActivityResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def date_occurred(self):
        """Gets the date_occurred of this ActivityResponse.  # noqa: E501


        :return: The date_occurred of this ActivityResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_occurred

    @date_occurred.setter
    def date_occurred(self, date_occurred):
        """Sets the date_occurred of this ActivityResponse.


        :param date_occurred: The date_occurred of this ActivityResponse.  # noqa: E501
        :type: datetime
        """
        if date_occurred is None:
            raise ValueError("Invalid value for `date_occurred`, must not be `None`")  # noqa: E501

        self._date_occurred = date_occurred

    @property
    def description(self):
        """Gets the description of this ActivityResponse.  # noqa: E501


        :return: The description of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ActivityResponse.


        :param description: The description of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def activity_category(self):
        """Gets the activity_category of this ActivityResponse.  # noqa: E501


        :return: The activity_category of this ActivityResponse.  # noqa: E501
        :rtype: CaseContentType
        """
        return self._activity_category

    @activity_category.setter
    def activity_category(self, activity_category):
        """Sets the activity_category of this ActivityResponse.


        :param activity_category: The activity_category of this ActivityResponse.  # noqa: E501
        :type: CaseContentType
        """
        if activity_category is None:
            raise ValueError("Invalid value for `activity_category`, must not be `None`")  # noqa: E501

        self._activity_category = activity_category

    @property
    def group(self):
        """Gets the group of this ActivityResponse.  # noqa: E501


        :return: The group of this ActivityResponse.  # noqa: E501
        :rtype: GroupChild
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this ActivityResponse.


        :param group: The group of this ActivityResponse.  # noqa: E501
        :type: GroupChild
        """

        self._group = group

    @property
    def indicator(self):
        """Gets the indicator of this ActivityResponse.  # noqa: E501


        :return: The indicator of this ActivityResponse.  # noqa: E501
        :rtype: IndicatorChild
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this ActivityResponse.


        :param indicator: The indicator of this ActivityResponse.  # noqa: E501
        :type: IndicatorChild
        """

        self._indicator = indicator

    @property
    def activity_codes(self):
        """Gets the activity_codes of this ActivityResponse.  # noqa: E501


        :return: The activity_codes of this ActivityResponse.  # noqa: E501
        :rtype: list[ActivityCodeChild]
        """
        return self._activity_codes

    @activity_codes.setter
    def activity_codes(self, activity_codes):
        """Sets the activity_codes of this ActivityResponse.


        :param activity_codes: The activity_codes of this ActivityResponse.  # noqa: E501
        :type: list[ActivityCodeChild]
        """
        if activity_codes is None:
            raise ValueError("Invalid value for `activity_codes`, must not be `None`")  # noqa: E501

        self._activity_codes = activity_codes

    @property
    def activity_document(self):
        """Gets the activity_document of this ActivityResponse.  # noqa: E501


        :return: The activity_document of this ActivityResponse.  # noqa: E501
        :rtype: DocumentChild
        """
        return self._activity_document

    @activity_document.setter
    def activity_document(self, activity_document):
        """Sets the activity_document of this ActivityResponse.


        :param activity_document: The activity_document of this ActivityResponse.  # noqa: E501
        :type: DocumentChild
        """
        if activity_document is None:
            raise ValueError("Invalid value for `activity_document`, must not be `None`")  # noqa: E501

        self._activity_document = activity_document

    @property
    def title(self):
        """Gets the title of this ActivityResponse.  # noqa: E501


        :return: The title of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ActivityResponse.


        :param title: The title of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def evidence_indicator(self):
        """Gets the evidence_indicator of this ActivityResponse.  # noqa: E501


        :return: The evidence_indicator of this ActivityResponse.  # noqa: E501
        :rtype: IndicatorChild
        """
        return self._evidence_indicator

    @evidence_indicator.setter
    def evidence_indicator(self, evidence_indicator):
        """Sets the evidence_indicator of this ActivityResponse.


        :param evidence_indicator: The evidence_indicator of this ActivityResponse.  # noqa: E501
        :type: IndicatorChild
        """

        self._evidence_indicator = evidence_indicator

    @property
    def created(self):
        """Gets the created of this ActivityResponse.  # noqa: E501


        :return: The created of this ActivityResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ActivityResponse.


        :param created: The created of this ActivityResponse.  # noqa: E501
        :type: datetime
        """
        if created is None:
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def created_by(self):
        """Gets the created_by of this ActivityResponse.  # noqa: E501


        :return: The created_by of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ActivityResponse.


        :param created_by: The created_by of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def modified(self):
        """Gets the modified of this ActivityResponse.  # noqa: E501


        :return: The modified of this ActivityResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this ActivityResponse.


        :param modified: The modified of this ActivityResponse.  # noqa: E501
        :type: datetime
        """
        if modified is None:
            raise ValueError("Invalid value for `modified`, must not be `None`")  # noqa: E501

        self._modified = modified

    @property
    def modified_by(self):
        """Gets the modified_by of this ActivityResponse.  # noqa: E501


        :return: The modified_by of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this ActivityResponse.


        :param modified_by: The modified_by of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if modified_by is None:
            raise ValueError("Invalid value for `modified_by`, must not be `None`")  # noqa: E501

        self._modified_by = modified_by

    @property
    def savings(self):
        """Gets the savings of this ActivityResponse.  # noqa: E501


        :return: The savings of this ActivityResponse.  # noqa: E501
        :rtype: float
        """
        return self._savings

    @savings.setter
    def savings(self, savings):
        """Sets the savings of this ActivityResponse.


        :param savings: The savings of this ActivityResponse.  # noqa: E501
        :type: float
        """
        if savings is None:
            raise ValueError("Invalid value for `savings`, must not be `None`")  # noqa: E501

        self._savings = savings

    @property
    def hierarchy(self):
        """Gets the hierarchy of this ActivityResponse.  # noqa: E501


        :return: The hierarchy of this ActivityResponse.  # noqa: E501
        :rtype: list[HierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this ActivityResponse.


        :param hierarchy: The hierarchy of this ActivityResponse.  # noqa: E501
        :type: list[HierarchyChild]
        """
        if hierarchy is None:
            raise ValueError("Invalid value for `hierarchy`, must not be `None`")  # noqa: E501

        self._hierarchy = hierarchy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DashboardCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'template_id': 'int',
        'corporation_id': 'str',
        'location_id': 'str',
        'time_range': 'WidgetTimeRangeValues',
        'power_bi_report_url': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'description': 'Description',
        'template_id': 'TemplateId',
        'corporation_id': 'CorporationId',
        'location_id': 'LocationId',
        'time_range': 'TimeRange',
        'power_bi_report_url': 'PowerBiReportUrl'
    }

    def __init__(self, name=None, description=None, template_id=None, corporation_id=None, location_id=None, time_range=None, power_bi_report_url=None):  # noqa: E501
        """DashboardCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._description = None
        self._template_id = None
        self._corporation_id = None
        self._location_id = None
        self._time_range = None
        self._power_bi_report_url = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        self.template_id = template_id
        self.corporation_id = corporation_id
        if location_id is not None:
            self.location_id = location_id
        if time_range is not None:
            self.time_range = time_range
        if power_bi_report_url is not None:
            self.power_bi_report_url = power_bi_report_url

    @property
    def name(self):
        """Gets the name of this DashboardCreateRequest.  # noqa: E501


        :return: The name of this DashboardCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DashboardCreateRequest.


        :param name: The name of this DashboardCreateRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this DashboardCreateRequest.  # noqa: E501


        :return: The description of this DashboardCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DashboardCreateRequest.


        :param description: The description of this DashboardCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def template_id(self):
        """Gets the template_id of this DashboardCreateRequest.  # noqa: E501


        :return: The template_id of this DashboardCreateRequest.  # noqa: E501
        :rtype: int
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this DashboardCreateRequest.


        :param template_id: The template_id of this DashboardCreateRequest.  # noqa: E501
        :type: int
        """
        if template_id is None:
            raise ValueError("Invalid value for `template_id`, must not be `None`")  # noqa: E501

        self._template_id = template_id

    @property
    def corporation_id(self):
        """Gets the corporation_id of this DashboardCreateRequest.  # noqa: E501


        :return: The corporation_id of this DashboardCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._corporation_id

    @corporation_id.setter
    def corporation_id(self, corporation_id):
        """Sets the corporation_id of this DashboardCreateRequest.


        :param corporation_id: The corporation_id of this DashboardCreateRequest.  # noqa: E501
        :type: str
        """
        if corporation_id is None:
            raise ValueError("Invalid value for `corporation_id`, must not be `None`")  # noqa: E501

        self._corporation_id = corporation_id

    @property
    def location_id(self):
        """Gets the location_id of this DashboardCreateRequest.  # noqa: E501


        :return: The location_id of this DashboardCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this DashboardCreateRequest.


        :param location_id: The location_id of this DashboardCreateRequest.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    @property
    def time_range(self):
        """Gets the time_range of this DashboardCreateRequest.  # noqa: E501


        :return: The time_range of this DashboardCreateRequest.  # noqa: E501
        :rtype: WidgetTimeRangeValues
        """
        return self._time_range

    @time_range.setter
    def time_range(self, time_range):
        """Sets the time_range of this DashboardCreateRequest.


        :param time_range: The time_range of this DashboardCreateRequest.  # noqa: E501
        :type: WidgetTimeRangeValues
        """

        self._time_range = time_range

    @property
    def power_bi_report_url(self):
        """Gets the power_bi_report_url of this DashboardCreateRequest.  # noqa: E501


        :return: The power_bi_report_url of this DashboardCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._power_bi_report_url

    @power_bi_report_url.setter
    def power_bi_report_url(self, power_bi_report_url):
        """Sets the power_bi_report_url of this DashboardCreateRequest.


        :param power_bi_report_url: The power_bi_report_url of this DashboardCreateRequest.  # noqa: E501
        :type: str
        """

        self._power_bi_report_url = power_bi_report_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DashboardCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RepeaterModelV3(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'serial_number': 'str',
        'radio_mac_address': 'str',
        'location_id': 'str',
        'location_name': 'str',
        'corporation_id': 'str',
        'corporation_name': 'str',
        'last_status_update': 'datetime',
        'active': 'bool',
        'type': 'ReceiverLocationTypeCodes'
    }

    attribute_map = {
        'id': 'Id',
        'serial_number': 'SerialNumber',
        'radio_mac_address': 'RadioMacAddress',
        'location_id': 'LocationId',
        'location_name': 'LocationName',
        'corporation_id': 'CorporationId',
        'corporation_name': 'CorporationName',
        'last_status_update': 'LastStatusUpdate',
        'active': 'Active',
        'type': 'Type'
    }

    def __init__(self, id=None, serial_number=None, radio_mac_address=None, location_id=None, location_name=None, corporation_id=None, corporation_name=None, last_status_update=None, active=None, type=None):  # noqa: E501
        """RepeaterModelV3 - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._serial_number = None
        self._radio_mac_address = None
        self._location_id = None
        self._location_name = None
        self._corporation_id = None
        self._corporation_name = None
        self._last_status_update = None
        self._active = None
        self._type = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.serial_number = serial_number
        if radio_mac_address is not None:
            self.radio_mac_address = radio_mac_address
        if location_id is not None:
            self.location_id = location_id
        if location_name is not None:
            self.location_name = location_name
        if corporation_id is not None:
            self.corporation_id = corporation_id
        if corporation_name is not None:
            self.corporation_name = corporation_name
        if last_status_update is not None:
            self.last_status_update = last_status_update
        if active is not None:
            self.active = active
        if type is not None:
            self.type = type

    @property
    def id(self):
        """Gets the id of this RepeaterModelV3.  # noqa: E501


        :return: The id of this RepeaterModelV3.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RepeaterModelV3.


        :param id: The id of this RepeaterModelV3.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def serial_number(self):
        """Gets the serial_number of this RepeaterModelV3.  # noqa: E501


        :return: The serial_number of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this RepeaterModelV3.


        :param serial_number: The serial_number of this RepeaterModelV3.  # noqa: E501
        :type: str
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def radio_mac_address(self):
        """Gets the radio_mac_address of this RepeaterModelV3.  # noqa: E501


        :return: The radio_mac_address of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._radio_mac_address

    @radio_mac_address.setter
    def radio_mac_address(self, radio_mac_address):
        """Sets the radio_mac_address of this RepeaterModelV3.


        :param radio_mac_address: The radio_mac_address of this RepeaterModelV3.  # noqa: E501
        :type: str
        """

        self._radio_mac_address = radio_mac_address

    @property
    def location_id(self):
        """Gets the location_id of this RepeaterModelV3.  # noqa: E501


        :return: The location_id of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this RepeaterModelV3.


        :param location_id: The location_id of this RepeaterModelV3.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    @property
    def location_name(self):
        """Gets the location_name of this RepeaterModelV3.  # noqa: E501


        :return: The location_name of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._location_name

    @location_name.setter
    def location_name(self, location_name):
        """Sets the location_name of this RepeaterModelV3.


        :param location_name: The location_name of this RepeaterModelV3.  # noqa: E501
        :type: str
        """

        self._location_name = location_name

    @property
    def corporation_id(self):
        """Gets the corporation_id of this RepeaterModelV3.  # noqa: E501


        :return: The corporation_id of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._corporation_id

    @corporation_id.setter
    def corporation_id(self, corporation_id):
        """Sets the corporation_id of this RepeaterModelV3.


        :param corporation_id: The corporation_id of this RepeaterModelV3.  # noqa: E501
        :type: str
        """

        self._corporation_id = corporation_id

    @property
    def corporation_name(self):
        """Gets the corporation_name of this RepeaterModelV3.  # noqa: E501


        :return: The corporation_name of this RepeaterModelV3.  # noqa: E501
        :rtype: str
        """
        return self._corporation_name

    @corporation_name.setter
    def corporation_name(self, corporation_name):
        """Sets the corporation_name of this RepeaterModelV3.


        :param corporation_name: The corporation_name of this RepeaterModelV3.  # noqa: E501
        :type: str
        """

        self._corporation_name = corporation_name

    @property
    def last_status_update(self):
        """Gets the last_status_update of this RepeaterModelV3.  # noqa: E501


        :return: The last_status_update of this RepeaterModelV3.  # noqa: E501
        :rtype: datetime
        """
        return self._last_status_update

    @last_status_update.setter
    def last_status_update(self, last_status_update):
        """Sets the last_status_update of this RepeaterModelV3.


        :param last_status_update: The last_status_update of this RepeaterModelV3.  # noqa: E501
        :type: datetime
        """

        self._last_status_update = last_status_update

    @property
    def active(self):
        """Gets the active of this RepeaterModelV3.  # noqa: E501


        :return: The active of this RepeaterModelV3.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this RepeaterModelV3.


        :param active: The active of this RepeaterModelV3.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def type(self):
        """Gets the type of this RepeaterModelV3.  # noqa: E501


        :return: The type of this RepeaterModelV3.  # noqa: E501
        :rtype: ReceiverLocationTypeCodes
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this RepeaterModelV3.


        :param type: The type of this RepeaterModelV3.  # noqa: E501
        :type: ReceiverLocationTypeCodes
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RepeaterModelV3, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RepeaterModelV3):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class ActivitiesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_activity(self, **kwargs):  # noqa: E501
        """Creates an Activity  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_activity(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ActivityCreateRequest body: Activity details
        :return: ActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_activity_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_activity_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_activity_with_http_info(self, **kwargs):  # noqa: E501
        """Creates an Activity  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_activity_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ActivityCreateRequest body: Activity details
        :return: ActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_activity" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Activities', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_activity(self, activity_id, **kwargs):  # noqa: E501
        """Deletes an activity  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_activity(activity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_id: Id of the activity (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_activity_with_http_info(activity_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_activity_with_http_info(activity_id, **kwargs)  # noqa: E501
            return data

    def delete_activity_with_http_info(self, activity_id, **kwargs):  # noqa: E501
        """Deletes an activity  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_activity_with_http_info(activity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_id: Id of the activity (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_activity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_id' is set
        if ('activity_id' not in params or
                params['activity_id'] is None):
            raise ValueError("Missing the required parameter `activity_id` when calling `delete_activity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_id' in params:
            path_params['activityId'] = params['activity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Activities/{activityId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activities(self, **kwargs):  # noqa: E501
        """Gets Activities  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activities(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `ActivityCategory` | CaseContentType | `eq, neq, in` | | `ActivityCodeId` | Guid | `eq, neq, in` | | `CreatedBy` | String | `eq, neq, like, in` | | `DateOccurred` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `Description` | String | `eq, neq, like, in` | | `GroupId` | Guid | `eq, neq, in` | | `IndicatorId` | Guid | `eq, neq, in` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `ModifiedBy` | String | `eq, neq, like, in` | | `Savings` | Single | `eq, neq, in, lt, gt, leq, geq` | | `Title` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `ActivityCategory` | CaseContentType | | `Created` | DateTime | | `CreatedBy` | String | | `DateOccurred` | DateTime | | `Description` | String | | `GroupName` | String | | `LocationName` | String | | `Modified` | DateTime | | `ModifiedBy` | String | | `Savings` | Single | | `Title` | String |
        :return: PagedResultsModelActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activities_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_activities_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_activities_with_http_info(self, **kwargs):  # noqa: E501
        """Gets Activities  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `ActivityCategory` | CaseContentType | `eq, neq, in` | | `ActivityCodeId` | Guid | `eq, neq, in` | | `CreatedBy` | String | `eq, neq, like, in` | | `DateOccurred` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `Description` | String | `eq, neq, like, in` | | `GroupId` | Guid | `eq, neq, in` | | `IndicatorId` | Guid | `eq, neq, in` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `ModifiedBy` | String | `eq, neq, like, in` | | `Savings` | Single | `eq, neq, in, lt, gt, leq, geq` | | `Title` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `ActivityCategory` | CaseContentType | | `Created` | DateTime | | `CreatedBy` | String | | `DateOccurred` | DateTime | | `Description` | String | | `GroupName` | String | | `LocationName` | String | | `Modified` | DateTime | | `ModifiedBy` | String | | `Savings` | Single | | `Title` | String |
        :return: PagedResultsModelActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activities" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Activities', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelActivityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity(self, activity_id, **kwargs):  # noqa: E501
        """Gets an Activity  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity(activity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_id: Id of the activity (required)
        :return: ActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_with_http_info(activity_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_with_http_info(activity_id, **kwargs)  # noqa: E501
            return data

    def get_activity_with_http_info(self, activity_id, **kwargs):  # noqa: E501
        """Gets an Activity  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_with_http_info(activity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_id: Id of the activity (required)
        :return: ActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_id' is set
        if ('activity_id' not in params or
                params['activity_id'] is None):
            raise ValueError("Missing the required parameter `activity_id` when calling `get_activity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_id' in params:
            path_params['activityId'] = params['activity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Activities/{activityId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_categories(self, **kwargs):  # noqa: E501
        """Gets activity categories  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_categories(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Name` | String |
        :return: PagedResultsModelActivityCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_categories_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_categories_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_activity_categories_with_http_info(self, **kwargs):  # noqa: E501
        """Gets activity categories  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_categories_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Name` | String |
        :return: PagedResultsModelActivityCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_categories" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Activities/Categories', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelActivityCategoryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_codes(self, category_type, **kwargs):  # noqa: E501
        """Gets activity codes for category type  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_codes(category_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CaseContentType category_type: The category to get the associated codes (required)
        :param str location_id: Optional param to get location specific codes
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Name` | String |
        :return: PagedResultsModelActivityCodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_codes_with_http_info(category_type, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_codes_with_http_info(category_type, **kwargs)  # noqa: E501
            return data

    def get_activity_codes_with_http_info(self, category_type, **kwargs):  # noqa: E501
        """Gets activity codes for category type  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_codes_with_http_info(category_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CaseContentType category_type: The category to get the associated codes (required)
        :param str location_id: Optional param to get location specific codes
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Name` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Name` | String |
        :return: PagedResultsModelActivityCodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['category_type', 'location_id', 'filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_codes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'category_type' is set
        if ('category_type' not in params or
                params['category_type'] is None):
            raise ValueError("Missing the required parameter `category_type` when calling `get_activity_codes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'category_type' in params:
            path_params['categoryType'] = params['category_type']  # noqa: E501

        query_params = []
        if 'location_id' in params:
            query_params.append(('locationId', params['location_id']))  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Activities/Categories/{categoryType}/codes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelActivityCodeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_activity(self, activity_id, **kwargs):  # noqa: E501
        """Updates an Activity  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_activity(activity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_id: (required)
        :param ActivityUpdateRequest body: Activity details
        :return: ActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_activity_with_http_info(activity_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_activity_with_http_info(activity_id, **kwargs)  # noqa: E501
            return data

    def update_activity_with_http_info(self, activity_id, **kwargs):  # noqa: E501
        """Updates an Activity  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_activity_with_http_info(activity_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_id: (required)
        :param ActivityUpdateRequest body: Activity details
        :return: ActivityResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_activity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_id' is set
        if ('activity_id' not in params or
                params['activity_id'] is None):
            raise ValueError("Missing the required parameter `activity_id` when calling `update_activity`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_id' in params:
            path_params['activityId'] = params['activity_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Activities/{activityId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.activities_api import ActivitiesApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestActivitiesApi(unittest.TestCase):
    """ActivitiesApi unit test stubs"""

    def setUp(self):
        self.api = ActivitiesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_activity(self):
        """Test case for create_activity

        Creates an Activity  # noqa: E501
        """
        pass

    def test_delete_activity(self):
        """Test case for delete_activity

        Deletes an activity  # noqa: E501
        """
        pass

    def test_get_activities(self):
        """Test case for get_activities

        Gets Activities  # noqa: E501
        """
        pass

    def test_get_activity(self):
        """Test case for get_activity

        Gets an Activity  # noqa: E501
        """
        pass

    def test_get_activity_categories(self):
        """Test case for get_activity_categories

        Gets activity categories  # noqa: E501
        """
        pass

    def test_get_activity_codes(self):
        """Test case for get_activity_codes

        Gets activity codes for category type  # noqa: E501
        """
        pass

    def test_update_activity(self):
        """Test case for update_activity

        Updates an Activity  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'date_occurred': 'datetime',
        'activity_category': 'CaseContentType',
        'title': 'str',
        'description': 'str',
        'activity_document': 'DocumentChild',
        'group_id': 'str',
        'indicator_id': 'str',
        'activity_code_ids': 'list[str]',
        'evidence_indicator_id': 'str',
        'savings': 'float'
    }

    attribute_map = {
        'date_occurred': 'DateOccurred',
        'activity_category': 'ActivityCategory',
        'title': 'Title',
        'description': 'Description',
        'activity_document': 'ActivityDocument',
        'group_id': 'GroupId',
        'indicator_id': 'IndicatorId',
        'activity_code_ids': 'ActivityCodeIds',
        'evidence_indicator_id': 'EvidenceIndicatorId',
        'savings': 'Savings'
    }

    def __init__(self, date_occurred=None, activity_category=None, title=None, description=None, activity_document=None, group_id=None, indicator_id=None, activity_code_ids=None, evidence_indicator_id=None, savings=None):  # noqa: E501
        """ActivityCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._date_occurred = None
        self._activity_category = None
        self._title = None
        self._description = None
        self._activity_document = None
        self._group_id = None
        self._indicator_id = None
        self._activity_code_ids = None
        self._evidence_indicator_id = None
        self._savings = None
        self.discriminator = None
        self.date_occurred = date_occurred
        self.activity_category = activity_category
        self.title = title
        if description is not None:
            self.description = description
        if activity_document is not None:
            self.activity_document = activity_document
        if group_id is not None:
            self.group_id = group_id
        if indicator_id is not None:
            self.indicator_id = indicator_id
        if activity_code_ids is not None:
            self.activity_code_ids = activity_code_ids
        if evidence_indicator_id is not None:
            self.evidence_indicator_id = evidence_indicator_id
        if savings is not None:
            self.savings = savings

    @property
    def date_occurred(self):
        """Gets the date_occurred of this ActivityCreateRequest.  # noqa: E501


        :return: The date_occurred of this ActivityCreateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._date_occurred

    @date_occurred.setter
    def date_occurred(self, date_occurred):
        """Sets the date_occurred of this ActivityCreateRequest.


        :param date_occurred: The date_occurred of this ActivityCreateRequest.  # noqa: E501
        :type: datetime
        """
        if date_occurred is None:
            raise ValueError("Invalid value for `date_occurred`, must not be `None`")  # noqa: E501

        self._date_occurred = date_occurred

    @property
    def activity_category(self):
        """Gets the activity_category of this ActivityCreateRequest.  # noqa: E501


        :return: The activity_category of this ActivityCreateRequest.  # noqa: E501
        :rtype: CaseContentType
        """
        return self._activity_category

    @activity_category.setter
    def activity_category(self, activity_category):
        """Sets the activity_category of this ActivityCreateRequest.


        :param activity_category: The activity_category of this ActivityCreateRequest.  # noqa: E501
        :type: CaseContentType
        """
        if activity_category is None:
            raise ValueError("Invalid value for `activity_category`, must not be `None`")  # noqa: E501

        self._activity_category = activity_category

    @property
    def title(self):
        """Gets the title of this ActivityCreateRequest.  # noqa: E501


        :return: The title of this ActivityCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this ActivityCreateRequest.


        :param title: The title of this ActivityCreateRequest.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def description(self):
        """Gets the description of this ActivityCreateRequest.  # noqa: E501


        :return: The description of this ActivityCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ActivityCreateRequest.


        :param description: The description of this ActivityCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def activity_document(self):
        """Gets the activity_document of this ActivityCreateRequest.  # noqa: E501


        :return: The activity_document of this ActivityCreateRequest.  # noqa: E501
        :rtype: DocumentChild
        """
        return self._activity_document

    @activity_document.setter
    def activity_document(self, activity_document):
        """Sets the activity_document of this ActivityCreateRequest.


        :param activity_document: The activity_document of this ActivityCreateRequest.  # noqa: E501
        :type: DocumentChild
        """

        self._activity_document = activity_document

    @property
    def group_id(self):
        """Gets the group_id of this ActivityCreateRequest.  # noqa: E501


        :return: The group_id of this ActivityCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this ActivityCreateRequest.


        :param group_id: The group_id of this ActivityCreateRequest.  # noqa: E501
        :type: str
        """

        self._group_id = group_id

    @property
    def indicator_id(self):
        """Gets the indicator_id of this ActivityCreateRequest.  # noqa: E501


        :return: The indicator_id of this ActivityCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._indicator_id

    @indicator_id.setter
    def indicator_id(self, indicator_id):
        """Sets the indicator_id of this ActivityCreateRequest.


        :param indicator_id: The indicator_id of this ActivityCreateRequest.  # noqa: E501
        :type: str
        """

        self._indicator_id = indicator_id

    @property
    def activity_code_ids(self):
        """Gets the activity_code_ids of this ActivityCreateRequest.  # noqa: E501


        :return: The activity_code_ids of this ActivityCreateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._activity_code_ids

    @activity_code_ids.setter
    def activity_code_ids(self, activity_code_ids):
        """Sets the activity_code_ids of this ActivityCreateRequest.


        :param activity_code_ids: The activity_code_ids of this ActivityCreateRequest.  # noqa: E501
        :type: list[str]
        """

        self._activity_code_ids = activity_code_ids

    @property
    def evidence_indicator_id(self):
        """Gets the evidence_indicator_id of this ActivityCreateRequest.  # noqa: E501


        :return: The evidence_indicator_id of this ActivityCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._evidence_indicator_id

    @evidence_indicator_id.setter
    def evidence_indicator_id(self, evidence_indicator_id):
        """Sets the evidence_indicator_id of this ActivityCreateRequest.


        :param evidence_indicator_id: The evidence_indicator_id of this ActivityCreateRequest.  # noqa: E501
        :type: str
        """

        self._evidence_indicator_id = evidence_indicator_id

    @property
    def savings(self):
        """Gets the savings of this ActivityCreateRequest.  # noqa: E501


        :return: The savings of this ActivityCreateRequest.  # noqa: E501
        :rtype: float
        """
        return self._savings

    @savings.setter
    def savings(self, savings):
        """Sets the savings of this ActivityCreateRequest.


        :param savings: The savings of this ActivityCreateRequest.  # noqa: E501
        :type: float
        """

        self._savings = savings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UserChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'str',
        'user_first_name': 'str',
        'user_last_name': 'str',
        'user_email': 'str'
    }

    attribute_map = {
        'user_id': 'UserId',
        'user_first_name': 'UserFirstName',
        'user_last_name': 'UserLastName',
        'user_email': 'UserEmail'
    }

    def __init__(self, user_id=None, user_first_name=None, user_last_name=None, user_email=None):  # noqa: E501
        """UserChild - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._user_first_name = None
        self._user_last_name = None
        self._user_email = None
        self.discriminator = None
        if user_id is not None:
            self.user_id = user_id
        if user_first_name is not None:
            self.user_first_name = user_first_name
        if user_last_name is not None:
            self.user_last_name = user_last_name
        if user_email is not None:
            self.user_email = user_email

    @property
    def user_id(self):
        """Gets the user_id of this UserChild.  # noqa: E501


        :return: The user_id of this UserChild.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserChild.


        :param user_id: The user_id of this UserChild.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_first_name(self):
        """Gets the user_first_name of this UserChild.  # noqa: E501


        :return: The user_first_name of this UserChild.  # noqa: E501
        :rtype: str
        """
        return self._user_first_name

    @user_first_name.setter
    def user_first_name(self, user_first_name):
        """Sets the user_first_name of this UserChild.


        :param user_first_name: The user_first_name of this UserChild.  # noqa: E501
        :type: str
        """

        self._user_first_name = user_first_name

    @property
    def user_last_name(self):
        """Gets the user_last_name of this UserChild.  # noqa: E501


        :return: The user_last_name of this UserChild.  # noqa: E501
        :rtype: str
        """
        return self._user_last_name

    @user_last_name.setter
    def user_last_name(self, user_last_name):
        """Sets the user_last_name of this UserChild.


        :param user_last_name: The user_last_name of this UserChild.  # noqa: E501
        :type: str
        """

        self._user_last_name = user_last_name

    @property
    def user_email(self):
        """Gets the user_email of this UserChild.  # noqa: E501


        :return: The user_email of this UserChild.  # noqa: E501
        :rtype: str
        """
        return self._user_email

    @user_email.setter
    def user_email(self, user_email):
        """Sets the user_email of this UserChild.


        :param user_email: The user_email of this UserChild.  # noqa: E501
        :type: str
        """

        self._user_email = user_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DashboardPermissionsUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_sentry_managed': 'bool',
        'is_visible_to_customers': 'bool'
    }

    attribute_map = {
        'is_sentry_managed': 'IsSentryManaged',
        'is_visible_to_customers': 'IsVisibleToCustomers'
    }

    def __init__(self, is_sentry_managed=None, is_visible_to_customers=None):  # noqa: E501
        """DashboardPermissionsUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._is_sentry_managed = None
        self._is_visible_to_customers = None
        self.discriminator = None
        self.is_sentry_managed = is_sentry_managed
        self.is_visible_to_customers = is_visible_to_customers

    @property
    def is_sentry_managed(self):
        """Gets the is_sentry_managed of this DashboardPermissionsUpdateRequest.  # noqa: E501


        :return: The is_sentry_managed of this DashboardPermissionsUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_sentry_managed

    @is_sentry_managed.setter
    def is_sentry_managed(self, is_sentry_managed):
        """Sets the is_sentry_managed of this DashboardPermissionsUpdateRequest.


        :param is_sentry_managed: The is_sentry_managed of this DashboardPermissionsUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_sentry_managed is None:
            raise ValueError("Invalid value for `is_sentry_managed`, must not be `None`")  # noqa: E501

        self._is_sentry_managed = is_sentry_managed

    @property
    def is_visible_to_customers(self):
        """Gets the is_visible_to_customers of this DashboardPermissionsUpdateRequest.  # noqa: E501


        :return: The is_visible_to_customers of this DashboardPermissionsUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_visible_to_customers

    @is_visible_to_customers.setter
    def is_visible_to_customers(self, is_visible_to_customers):
        """Sets the is_visible_to_customers of this DashboardPermissionsUpdateRequest.


        :param is_visible_to_customers: The is_visible_to_customers of this DashboardPermissionsUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_visible_to_customers is None:
            raise ValueError("Invalid value for `is_visible_to_customers`, must not be `None`")  # noqa: E501

        self._is_visible_to_customers = is_visible_to_customers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DashboardPermissionsUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardPermissionsUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IdentityProviderCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'username_identifiers': 'list[str]',
        'corporation_id': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'username_identifiers': 'UsernameIdentifiers',
        'corporation_id': 'CorporationId'
    }

    def __init__(self, name=None, username_identifiers=None, corporation_id=None):  # noqa: E501
        """IdentityProviderCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._username_identifiers = None
        self._corporation_id = None
        self.discriminator = None
        self.name = name
        if username_identifiers is not None:
            self.username_identifiers = username_identifiers
        self.corporation_id = corporation_id

    @property
    def name(self):
        """Gets the name of this IdentityProviderCreateRequest.  # noqa: E501


        :return: The name of this IdentityProviderCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IdentityProviderCreateRequest.


        :param name: The name of this IdentityProviderCreateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def username_identifiers(self):
        """Gets the username_identifiers of this IdentityProviderCreateRequest.  # noqa: E501


        :return: The username_identifiers of this IdentityProviderCreateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._username_identifiers

    @username_identifiers.setter
    def username_identifiers(self, username_identifiers):
        """Sets the username_identifiers of this IdentityProviderCreateRequest.


        :param username_identifiers: The username_identifiers of this IdentityProviderCreateRequest.  # noqa: E501
        :type: list[str]
        """

        self._username_identifiers = username_identifiers

    @property
    def corporation_id(self):
        """Gets the corporation_id of this IdentityProviderCreateRequest.  # noqa: E501


        :return: The corporation_id of this IdentityProviderCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._corporation_id

    @corporation_id.setter
    def corporation_id(self, corporation_id):
        """Sets the corporation_id of this IdentityProviderCreateRequest.


        :param corporation_id: The corporation_id of this IdentityProviderCreateRequest.  # noqa: E501
        :type: str
        """
        if corporation_id is None:
            raise ValueError("Invalid value for `corporation_id`, must not be `None`")  # noqa: E501

        self._corporation_id = corporation_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IdentityProviderCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IdentityProviderCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
